==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/core/subtitle.h <==
#ifndef SUBTITLE_H
#define SUBTITLE_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "ranges.h"
#include "sctime.h"
#include "subtitleline.h"
#include "actionmanager.h"
#include "formatdata.h"

#include <qobject.h>
#include <qstring.h>
#include <qstringlist.h>

namespace SubtitleComposer
{
	class CompositeAction;

	class Subtitle : public QObject
	{
		Q_OBJECT

		friend class SubtitleLine;
		friend class SubtitleIterator;

		friend class SubtitleAction;
		friend class SetFramesPerSecondAction;
		friend class InsertLinesAction;
		friend class RemoveLinesAction;
		friend class MoveLineAction;

		friend class SubtitleLineAction;

		friend class SubtitleCompositeActionExecutor;

		friend class Format;

		public:

			static double defaultFramesPerSecond();
			static void setDefaultFramesPerSecond( double framesPerSecond );

			Subtitle( double framesPerSecond=defaultFramesPerSecond() );
			virtual ~Subtitle();

			bool isPrimaryDirty() const;
			void clearPrimaryDirty();

			bool isSecondaryDirty() const;
			void clearSecondaryDirty();

			ActionManager& actionManager();
			const ActionManager& actionManager() const;

			double framesPerSecond() const;
			void setFramesPerSecond( double framesPerSecond );
			void changeFramesPerSecond( double toFramesPerSecond, double fromFramesPerSecond=-1.0 );

			unsigned linesCount() const;

			SubtitleLine* line( unsigned index );
			const SubtitleLine* line( unsigned index ) const;
			SubtitleLine* firstLine();
			const SubtitleLine* firstLine() const;
			SubtitleLine* lastLine();
			const SubtitleLine* lastLine() const;

			SubtitleLine* prevLine( const SubtitleLine* line );
			SubtitleLine* nextLine( const SubtitleLine* line );

			unsigned lineNumber( const SubtitleLine* line ) const;
			int lineIndex( const SubtitleLine* line ) const;

			void insertLine( SubtitleLine* line, unsigned index=Range::MaxIndex );
			void insertLines( const QPtrList<SubtitleLine>& lines, unsigned index=Range::MaxIndex );
			SubtitleLine* insertNewLine( unsigned index, bool timeAfter, SubtitleLine::OpMode mode=SubtitleLine::Both );
			void removeLines( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Both );

			void swapTexts( const RangeList& ranges );

			void splitLines( const RangeList& ranges );
			void joinLines( const RangeList& ranges );

			void shiftLines( const RangeList& ranges, long msecs );
			void adjustLines( const Range& range, long firstTime, long lastTime );
			void sortLines( const Range& range );

			void applyDurationLimits( const RangeList& ranges, const Time& minDuration, const Time& maxDuration, bool canOverlap );
			void setMaximunDurations( const RangeList& ranges );
			void setAutoDurations( const RangeList& ranges, unsigned charMsecs, unsigned wordMsecs, unsigned lineMsecs, bool canOverlap, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void fixOverlappingLines( const RangeList& ranges, const Time& minInterval=100 );

			void fixPunctuation( const RangeList& ranges, bool spaces, bool quotes, bool engI, bool ellipsis, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void lowerCase( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void upperCase( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void titleCase( const RangeList& ranges, bool lowerFirst=false, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void sentenceCase( const RangeList& ranges, bool lowerFirst=false, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void adjustTexts( const RangeList& ranges, unsigned minLengthForLineBreak, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void unbreakTexts( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void simplifySpaces( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void syncToSubtitle( const Subtitle& referenceSubtitle );
			void appendSubtitle( const Subtitle& subtitle, long shiftMsecsBeforeAppend );
			void splitSubtitle( Subtitle& subtitle, const Time& splitTime, bool shiftSplittedLines );

			void setStyleFlags( const RangeList& ranges, int styleFlags );
			void setStyleFlags( const RangeList& ranges, int styleFlags, bool value );
			void toggleStyleFlag( const RangeList& ranges, SubtitleLine::StyleFlag styleFlag );

			void setMarked( const RangeList& ranges, bool value );
			void toggleMarked( const RangeList& ranges );

			void clearErrors( const RangeList& ranges, int errorFlags );
			void checkErrors( const RangeList& ranges, int errorFlags, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines );
			void recheckErrors( const RangeList& ranges, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines );

		signals:

			void primaryDirtyStateChanged( bool dirty );
			void secondaryDirtyStateChanged( bool dirty );

			void framesPerSecondChanged( double fps );
			void linesInserted( unsigned firstIndex, unsigned lastIndex );
			void linesRemoved( unsigned firstIndex, unsigned lastIndex );

		private:

			FormatData* const formatData() const;
			void setFormatData( const FormatData* formatData );

			void beginCompositeAction( const QString& title, bool immediateExecution=true, bool delaySignals=true );
			void endCompositeAction();
			void processAction( Action* action );

			void incrementState( int dirtyMode );
			void decrementState( int dirtyMode );

		private:

			ActionManager m_actionManager;
			unsigned long m_primaryState;
			unsigned long m_primaryCleanState;
			unsigned long m_secondaryState;
			unsigned long m_secondaryCleanState;

			CompositeAction* m_compositeAction;
			unsigned long m_compositeActionDepth;

			double m_framesPerSecond;
			mutable QPtrList<SubtitleLine> m_lines;

			FormatData* m_formatData;

			static double s_defaultFramesPerSecond;
	};

	class SubtitleCompositeActionExecutor
	{
		public:

			SubtitleCompositeActionExecutor( Subtitle& subtitle, const QString& title );
			~SubtitleCompositeActionExecutor();

		private:

			Subtitle& m_subtitle;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/core/subtitle.h <==
#ifndef SUBTITLE_H
#define SUBTITLE_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "range.h"
#include "rangelist.h"
#include "sctime.h"
#include "sstring.h"
#include "subtitleline.h"
#include "actionmanager.h"
#include "formatdata.h"

#include <qobject.h>
#include <qstring.h>
#include <qstringlist.h>

namespace SubtitleComposer
{
	class CompositeAction;

	class Subtitle : public QObject
	{
		Q_OBJECT

		friend class SubtitleLine;
		friend class SubtitleIterator;

		friend class SubtitleAction;
		friend class SetFramesPerSecondAction;
		friend class InsertLinesAction;
		friend class RemoveLinesAction;
		friend class MoveLineAction;

		friend class SubtitleLineAction;

		friend class SubtitleCompositeActionExecutor;

		friend class Format;

		public:

			static double defaultFramesPerSecond();
			static void setDefaultFramesPerSecond( double framesPerSecond );

			Subtitle( double framesPerSecond=defaultFramesPerSecond() );
			virtual ~Subtitle();

			void setPrimaryData( const Subtitle& subtitle, bool fromPrimaryTexts );
			void clearPrimaryTextData();

			void setSecondaryData( const Subtitle& subtitle, bool fromPrimaryTexts );
			void clearSecondaryTextData();

			bool isPrimaryDirty() const;
			void clearPrimaryDirty();

			bool isSecondaryDirty() const;
			void clearSecondaryDirty();

			ActionManager& actionManager();
			const ActionManager& actionManager() const;

			double framesPerSecond() const;
			void setFramesPerSecond( double framesPerSecond );
			void changeFramesPerSecond( double toFramesPerSecond, double fromFramesPerSecond=-1.0 );

			unsigned linesCount() const;

			SubtitleLine* line( unsigned index );
			const SubtitleLine* line( unsigned index ) const;
			SubtitleLine* firstLine();
			const SubtitleLine* firstLine() const;
			SubtitleLine* lastLine();
			const SubtitleLine* lastLine() const;

			SubtitleLine* prevLine( const SubtitleLine* line );
			SubtitleLine* nextLine( const SubtitleLine* line );

			unsigned lineNumber( const SubtitleLine* line ) const;
			int lineIndex( const SubtitleLine* line ) const;

			void insertLine( SubtitleLine* line, unsigned index=Range::MaxIndex );
			void insertLines( const QPtrList<SubtitleLine>& lines, unsigned index=Range::MaxIndex );
			SubtitleLine* insertNewLine( unsigned index, bool timeAfter, SubtitleLine::OpMode mode=SubtitleLine::Both );
			void removeLines( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Both );

			void swapTexts( const RangeList& ranges );

			void splitLines( const RangeList& ranges );
			void joinLines( const RangeList& ranges );

			void shiftLines( const RangeList& ranges, long msecs );
			void adjustLines( const Range& range, long firstTime, long lastTime );
			void sortLines( const Range& range );

			void applyDurationLimits( const RangeList& ranges, const Time& minDuration, const Time& maxDuration, bool canOverlap );
			void setMaximunDurations( const RangeList& ranges );
			void setAutoDurations( const RangeList& ranges, unsigned charMsecs, unsigned wordMsecs, unsigned lineMsecs, bool canOverlap, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void fixOverlappingLines( const RangeList& ranges, const Time& minInterval=100 );

			void fixPunctuation( const RangeList& ranges, bool spaces, bool quotes, bool engI, bool ellipsis, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void lowerCase( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void upperCase( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void titleCase( const RangeList& ranges, bool lowerFirst=false, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void sentenceCase( const RangeList& ranges, bool lowerFirst=false, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void adjustTexts( const RangeList& ranges, unsigned minLengthForLineBreak, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void unbreakTexts( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );
			void simplifySpaces( const RangeList& ranges, SubtitleLine::OpMode mode=SubtitleLine::Primary );

			void syncToSubtitle( const Subtitle& refSubtitle );
			void appendSubtitle( const Subtitle& srcSubtitle, long shiftMsecsBeforeAppend );
			void splitSubtitle( Subtitle& dstSubtitle, const Time& splitTime, bool shiftSplittedLines );

			void setStyleFlags( const RangeList& ranges, int styleFlags );
			void setStyleFlags( const RangeList& ranges, int styleFlags, bool on );
			void toggleStyleFlag( const RangeList& ranges, SString::StyleFlag styleFlag );

			void setMarked( const RangeList& ranges, bool value );
			void toggleMarked( const RangeList& ranges );

			void clearErrors( const RangeList& ranges, int errorFlags );
			void checkErrors( const RangeList& ranges, int errorFlags, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines );
			void recheckErrors( const RangeList& ranges, int minDurationMsecs, int maxDurationMsecs, int minMsecsPerChar, int maxMsecsPerChar, int maxChars, int maxLines );

		signals:

			void primaryDirtyStateChanged( bool dirty );
			void secondaryDirtyStateChanged( bool dirty );

			void framesPerSecondChanged( double fps );
			void linesInserted( unsigned firstIndex, unsigned lastIndex );
			void linesRemoved( unsigned firstIndex, unsigned lastIndex );

		private:

			FormatData* const formatData() const;
			void setFormatData( const FormatData* formatData );

			void beginCompositeAction( const QString& title, bool immediateExecution=true, bool delaySignals=true );
			void endCompositeAction();
			void processAction( Action* action );

			void incrementState( int dirtyMode );
			void decrementState( int dirtyMode );

		private:

			ActionManager m_actionManager;
			unsigned long m_primaryState;
			unsigned long m_primaryCleanState;
			unsigned long m_secondaryState;
			unsigned long m_secondaryCleanState;

			CompositeAction* m_compositeAction;
			unsigned long m_compositeActionDepth;

			double m_framesPerSecond;
			mutable QPtrList<SubtitleLine> m_lines;

			FormatData* m_formatData;

			static double s_defaultFramesPerSecond;
	};

	class SubtitleCompositeActionExecutor
	{
		public:

			SubtitleCompositeActionExecutor( Subtitle& subtitle, const QString& title );
			~SubtitleCompositeActionExecutor();

		private:

			Subtitle& m_subtitle;
	};
}

#endif
